==> quasar-1.5.9.jar: META-INF/resources/webjars/quasar/1.5.9/icon-set/fontawesome-v5-pro.js <==
export default {
  name: 'fontawesome-v5-pro',
  type: {
    positive: 'fal fa-check',
    negative: 'fal fa-exclamation-triangle',
    info: 'fal fa-info-circle',
    warning: 'fal fa-exclamation'
  },
  arrow: {
    up: 'fal fa-arrow-up',
    right: 'fal fa-arrow-right',
    down: 'fal fa-arrow-down',
    left: 'fal fa-arrow-left',
    dropdown: 'fal fa-caret-down'
  },
  chevron: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },
  colorPicker: {
    spectrum: 'fal fa-eye-dropper',
    tune: 'fal fa-sliders-h',
    palette: 'fal fa-swatchbook'
  },
  pullToRefresh: {
    icon: 'fal fa-sync-alt'
  },
  carousel: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right', // TODO
    navigationIcon: 'fal fa-circle',
    thumbnails: 'fal fa-th'
  },
  chip: {
    remove: 'fal fa-times-circle',
    selected: 'fal fa-check'
  },
  datetime: {
    arrowLeft: 'fal fa-chevron-left',
    arrowRight: 'fal fa-chevron-right',
    now: 'fal fa-clock',
    today: 'fal fa-calendar-check'
  },
  editor: {
    bold: 'fal fa-bold',
    italic: 'fal fa-italic',
    strikethrough: 'fal fa-strikethrough',
    underline: 'fal fa-underline',
    unorderedList: 'fal fa-list-ul',
    orderedList: 'fal fa-list-ol',
    subscript: 'fal fa-subscript',
    superscript: 'fal fa-superscript',
    hyperlink: 'fal fa-link',
    toggleFullscreen: 'fal fa-expand-arrows-alt',
    quote: 'fal fa-quote-right',
    left: 'fal fa-align-left',
    center: 'fal fa-align-center',
    right: 'fal fa-align-right',
    justify: 'fal fa-align-justify',
    print: 'fal fa-print',
    outdent: 'fal fa-outdent',
    indent: 'fal fa-indent',
    removeFormat: 'fal fa-eraser',
    formatting: 'fal fa-heading',
    fontSize: 'fal fa-text-height',
    align: 'fal fa-align-left',
    hr: 'fal fa-minus-square',
    undo: 'fal fa-undo',
    redo: 'fal fa-redo',
    heading: 'fal fa-heading',
    code: 'fal fa-code',
    size: 'fal fa-text-height',
    font: 'fal fa-font',
    viewSource: 'fal fa-code'
  },
  expansionItem: {
    icon: 'fal fa-chevron-down',
    denseIcon: 'fal fa-caret-down'
  },
  fab: {
    icon: 'fal fa-plus',
    activeIcon: 'fal fa-times'
  },
  field: {
    clear: 'fal fa-times-circle',
    error: 'fal fa-exclamation-circle'
  },
  pagination: {
    first: 'fal fa-step-backward',
    prev: 'fal fa-chevron-left',
    next: 'fal fa-chevron-right',
    last: 'fal fa-step-forward'
  },
  rating: {
    icon: 'fal fa-star'
  },
  stepper: {
    done: 'fal fa-check',
    active: 'fal fa-pencil-alt',
    error: 'fal fa-exclamation-triangle'
  },
  tabs: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right',
    up: 'fal fa-chevron-up',
    down: 'fal fa-chevron-down'
  },
  table: {
    arrowUp: 'fal fa-long-arrow-up',
    warning: 'fal fa-exclamation-triangle',
    prevPage: 'fal fa-chevron-left',
    nextPage: 'fal fa-chevron-right'
  },
  tree: {
    icon: 'fal fa-play'
  },
  uploader: {
    done: 'fal fa-check',
    clear: 'fal fa-times',
    add: 'fal fa-plus-square',
    upload: 'fal fa-upload',
    removeQueue: 'fal fa-stream',
    removeUploaded: 'fal fa-clipboard-check'
  }
}

==> quasar-1.9.16.jar: META-INF/resources/webjars/quasar/1.9.16/icon-set/fontawesome-v5-pro.js <==
export default {
  name: 'fontawesome-v5-pro',
  type: {
    positive: 'fal fa-check',
    negative: 'fal fa-exclamation-triangle',
    info: 'fal fa-info-circle',
    warning: 'fal fa-exclamation'
  },
  arrow: {
    up: 'fal fa-arrow-up',
    right: 'fal fa-arrow-right',
    down: 'fal fa-arrow-down',
    left: 'fal fa-arrow-left',
    dropdown: 'fal fa-caret-down'
  },
  chevron: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },
  colorPicker: {
    spectrum: 'fal fa-eye-dropper',
    tune: 'fal fa-sliders-h',
    palette: 'fal fa-swatchbook'
  },
  pullToRefresh: {
    icon: 'fal fa-sync-alt'
  },
  carousel: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right', // TODO
    up: 'fal fa-chevron-up',
    down: 'fal fa-chevron-down',
    navigationIcon: 'fal fa-circle'
  },
  chip: {
    remove: 'fal fa-times-circle',
    selected: 'fal fa-check'
  },
  datetime: {
    arrowLeft: 'fal fa-chevron-left',
    arrowRight: 'fal fa-chevron-right',
    now: 'fal fa-clock',
    today: 'fal fa-calendar-check'
  },
  editor: {
    bold: 'fal fa-bold',
    italic: 'fal fa-italic',
    strikethrough: 'fal fa-strikethrough',
    underline: 'fal fa-underline',
    unorderedList: 'fal fa-list-ul',
    orderedList: 'fal fa-list-ol',
    subscript: 'fal fa-subscript',
    superscript: 'fal fa-superscript',
    hyperlink: 'fal fa-link',
    toggleFullscreen: 'fal fa-expand-arrows-alt',
    quote: 'fal fa-quote-right',
    left: 'fal fa-align-left',
    center: 'fal fa-align-center',
    right: 'fal fa-align-right',
    justify: 'fal fa-align-justify',
    print: 'fal fa-print',
    outdent: 'fal fa-outdent',
    indent: 'fal fa-indent',
    removeFormat: 'fal fa-eraser',
    formatting: 'fal fa-heading',
    fontSize: 'fal fa-text-height',
    align: 'fal fa-align-left',
    hr: 'fal fa-minus-square',
    undo: 'fal fa-undo',
    redo: 'fal fa-redo',
    heading: 'fal fa-heading',
    code: 'fal fa-code',
    size: 'fal fa-text-height',
    font: 'fal fa-font',
    viewSource: 'fal fa-code'
  },
  expansionItem: {
    icon: 'fal fa-chevron-down',
    denseIcon: 'fal fa-caret-down'
  },
  fab: {
    icon: 'fal fa-plus',
    activeIcon: 'fal fa-times'
  },
  field: {
    clear: 'fal fa-times-circle',
    error: 'fal fa-exclamation-circle'
  },
  pagination: {
    first: 'fal fa-step-backward',
    prev: 'fal fa-chevron-left',
    next: 'fal fa-chevron-right',
    last: 'fal fa-step-forward'
  },
  rating: {
    icon: 'fal fa-star'
  },
  stepper: {
    done: 'fal fa-check',
    active: 'fal fa-pencil-alt',
    error: 'fal fa-exclamation-triangle'
  },
  tabs: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right',
    up: 'fal fa-chevron-up',
    down: 'fal fa-chevron-down'
  },
  table: {
    arrowUp: 'fal fa-long-arrow-up',
    warning: 'fal fa-exclamation-triangle',
    prevPage: 'fal fa-chevron-left',
    nextPage: 'fal fa-chevron-right'
  },
  tree: {
    icon: 'fal fa-play'
  },
  uploader: {
    done: 'fal fa-check',
    clear: 'fal fa-times',
    add: 'fal fa-plus-square',
    upload: 'fal fa-upload',
    removeQueue: 'fal fa-stream',
    removeUploaded: 'fal fa-clipboard-check'
  }
}
